require 'cocoapods-packager-ext/ext/downloader/lnpath'
require 'cocoapods-packager-ext/ext/downloader_ext'
require 'cocoapods-packager-ext/ext/pod_utils'

module Pod
  class Command
    # This is an example of a cocoapods plugin adding a top-level subcommand
    # to the 'pod' command.
    #
    # You can also create subcommands of existing or new commands. Say you
    # wanted to add a subcommand to `list` to show newly deprecated pods,
    # (e.g. `pod list deprecated`), there are a few things that would need
    # to change.
    #
    # - move this file to `lib/pod/command/list/deprecated.rb` and update
    #   the class to exist in the the Pod::Command::List namespace
    # - change this class to extend from `List` instead of `Command`. This
    #   tells the plugin system that it is a subcommand of `list`.
    # - edit `lib/cocoapods_plugins.rb` to require this file
    #
    # @todo Create a PR to add your plugin to CocoaPods/cocoapods.org
    #       in the `plugins.json` file, once your plugin is released.
    #
    class Package
        class << self

            begin
                alias options_t options
                def options
                    o = options_t
                    o.push(['--archs','select archs'])
                    o.push(['--podfile','select deps version from podfile'])
                    o.push(['--platform','select platform'])
                    o.concat(super)
                end
            rescue
                return 
            end
           

        end

        alias initialize_t initialize
        def initialize(argv)
            @exclude_dep_items = argv.option('exclude-deps','').split(',')
            @select_archs = argv.option('archs','').split(',')
            @podfile = argv.option('podfile','')
            @platform = argv.option('platform','')
            initialize_t argv
        end

        alias build_in_sandbox_t build_in_sandbox
        def build_in_sandbox(platform)
            config.installation_root  = Pathname.new(Dir.pwd)
            config.sandbox_root       = 'Pods'

            static_sandbox = build_static_sandbox(@dynamic)
            static_installer = install_pod(platform.name, static_sandbox)

            if @dynamic
                dynamic_sandbox = build_dynamic_sandbox(static_sandbox, static_installer)
                install_dynamic_pod(dynamic_sandbox, static_sandbox, static_installer, platform)
            end

            begin
                perform_build(platform, static_sandbox, dynamic_sandbox, static_installer)
            ensure # in case the build fails; see Builder#xcodebuild.
                if ENV['ENABLE_BACKUP_WORKSPACE'] && (ENV['ENABLE_BACKUP_WORKSPACE'].upcase == 'YES' || ENV['ENABLE_BACKUP_WORKSPACE'].upcase == 'TRUE')
                    UI.message 'Backup Workspace'
                else
                    UI.message 'Delete Workspace'
                    Pathname.new(config.sandbox_root).rmtree
                    FileUtils.rm_f('Podfile.lock')
                end
            end
        end

        def spec_library(platform)
            spec = <<RB
  s.#{platform.name.to_s}.deployment_target    = '#{platform.deployment_target}'
  s.#{platform.name.to_s}.vendored_libraries  = ['#{platform.name.to_s}/*.a']
  s.#{platform.name.to_s}.public_header_files = ['#{platform.name.to_s}/Headers/*.{h}']
  s.#{platform.name.to_s}.source_files = ['#{platform.name.to_s}/Headers/*.{h}',"#{platform.name.to_s}/Modules/module.modulemap"]
  s.#{platform.name.to_s}.resource = ['#{platform.name.to_s}/Resources/*.bundle']
  s.#{platform.name.to_s}.module_map   = "#{platform.name.to_s}/Modules/module.modulemap"
RB
        end

        def spec_framework(platform)
            spec = <<RB
  s.#{platform.name.to_s}.public_header_files = ['#{platform.name.to_s}/Headers/*.{h}']
  s.#{platform.name.to_s}.source_files = ['#{platform.name.to_s}/**/Headers/*.{h}']
  s.#{platform.name.to_s}.resource = ['#{platform.name.to_s}/**/Resources/*.bundle']
  s.#{platform.name.to_s}.module_map   = "#{platform.name.to_s}/**/Modules/module.modulemap"
RB
        end

        alias build_package_t build_package
        def build_package
            if @platform == ''
                build_package_t
            else
                builder = SpecBuilder.new(@spec, @source, @embedded, @dynamic)
                newspec = builder.spec_metadata
                
                @spec.available_platforms.each do |platform|
                    if @platform.include?(platform.name.to_s)
                        UI.puts 'build package platform:'+platform.name.to_s
                        build_in_sandbox(platform)
                        if @library
                            newspec += spec_library(platform)
                        else
                            newspec += builder.spec_platform(platform)
                        end


                    else
                        UI.puts 'jump build platforms:'+platform.to_s
                    end
                end

                newspec += builder.spec_close
                File.open(@spec.name + '.podspec', 'w') { |file| file.write(newspec) }
            end

        end

        def clean_dummy_files(path)
            Dir.entries(path).each do |sub|
                if sub != '.' && sub != '..'
                    if File.directory?("#{path}/#{sub}")
                        clean_dummy_files("#{path}/#{sub}")
                    else
                        if(sub =~ /-dummy.m$/)
                            File.open("#{path}/#{sub}",'w')do |file|
                                file.write('')
                                UI.message " - clean dummy file:#{sub}"
                            end
                        end
                    end
                end
            end
        end

        alias perform_build_t perform_build
        def perform_build(platform, static_sandbox, dynamic_sandbox,static_installer)
            if @select_archs.length > 0 || @exclude_dep_items.length > 0
                static_sandbox_root = config.sandbox_root.to_s

                if @dynamic
                    static_sandbox_root = "#{static_sandbox_root}/#{static_sandbox.root.to_s.split('/').last}"
                    dynamic_sandbox_root = "#{config.sandbox_root}/#{dynamic_sandbox.root.to_s.split('/').last}"
                end

                if (ENV['ENABLE_CLEAN_DUMMY_FILE'] && (ENV['ENABLE_CLEAN_DUMMY_FILE'].upcase == 'YES' || ENV['ENABLE_CLEAN_DUMMY_FILE'].upcase == 'TRUE'))
                    UI.title 'Clean Dummy Files' do
                        clean_dummy_files(static_sandbox.target_support_files_root)
                        if @dynamic
                            clean_dummy_files(dynamic_sandbox.target_support_files_root)
                        end
                    end
                else
                    UI.puts 'Jump clean dummy files'
                end

                builder = Pod::Builder.new(
                  platform,
                  static_installer,
                  @source_dir,
                  static_sandbox_root,
                  dynamic_sandbox_root,
                  static_sandbox.public_headers.root,
                  @spec,
                  @embedded,
                  @mangle,
                  @dynamic,
                  @config,
                  @bundle_identifier,
                  @exclude_deps,
                  @exclude_dep_items,
                  @select_archs
                )

                builder.build(@package_type)

                return unless @embedded
                builder.link_embedded_resources
            else
                perform_build_t(platform,static_sandbox,dynamic_sandbox,static_installer)
            end
        end

    end
  end
end
