module Pod
  class Command
    class Package

      # @param [Pod::Installer] static_installer
      #
      # @return [Pod::PodTarget]
      #
      alias build_dynamic_target_t build_dynamic_target

      def build_dynamic_target(dynamic_sandbox, static_installer, platform)
        spec_targets = static_installer.pod_targets.select do |target|
          target.name == @spec.name
        end
        static_target = spec_targets[0]

        file_accessors = create_file_accessors(static_target, dynamic_sandbox)

        archs = []
        dynamic_target = Pod::PodTarget.new(dynamic_sandbox, BuildType.dynamic_framework, static_target.user_build_configurations, archs, platform, static_target.specs, static_target.target_definitions, file_accessors)
        ln_source_to_dynamic_target(static_installer,dynamic_sandbox)
        dynamic_target
      end
      alias copy_dynamic_target_t copy_dynamic_target
      def copy_dynamic_target(static_sandbox, _dynamic_target, dynamic_sandbox)
        if Dir.exist? static_sandbox.root+@spec.name
          command = "ln -sf #{static_sandbox.root}/#{@spec.name} #{dynamic_sandbox.root}"
          `#{command}`
        end
      end

      def ln_source_to_dynamic_target(static_installer, dynamic_sandbox)
        if not Dir.exist? static_installer.sandbox.root+@spec.name
          file_accessors = static_installer.pod_targets.select { |t| t.pod_name == @spec.name }.flat_map(&:file_accessors)
          if file_accessors && file_accessors.length > 0
            source_root = file_accessors[0].path_list.root
            command = "ln -sf #{source_root} #{dynamic_sandbox.root}/#{@spec.name}"
            `#{command}`
          else
            UI.puts "#{@spec.name} 根目录找不到"

          end
        end
      end

      alias write_pod_project_t write_pod_project
      def write_pod_project(dynamic_project, dynamic_sandbox)
        UI.message "- Writing Xcode project file to #{UI.path dynamic_sandbox.project_path}" do
          dynamic_project.pods.remove_from_project if dynamic_project.pods.empty?
          dynamic_project.development_pods.remove_from_project if dynamic_project.development_pods.empty?
          dynamic_project.sort(:groups_position => :below)
          dynamic_project.recreate_user_schemes(false)

          # Edit search paths so that we can find our dependency headers
          dynamic_project.targets.first.build_configuration_list.build_configurations.each do |config|
            header_path = Dir.glob("#{Dir.pwd}/Pods/Static/Headers/*/*")
            header_path.push "#{Dir.pwd}/Pods/Static/Headers/Public"
            header_path.push "#{Dir.pwd}/Pods/Static/Headers/Private"
            header_path.reject! {|item|item.split('/').last == dynamic_project.targets.first.name}
            header_path = header_path.join " "
            config.build_settings['HEADER_SEARCH_PATHS'] = "$(inherited) #{header_path}"
            config.build_settings['USER_HEADER_SEARCH_PATHS'] = "$(inherited) #{header_path}"
            config.build_settings['OTHER_LDFLAGS'] = '$(inherited) -ObjC'

            if ENV['DISABLE_BITCODE'] && (ENV['DISABLE_BITCODE'].upcase == 'YES' || ENV['DISABLE_BITCODE'].upcase == 'TRUE')
              config.build_settings['ENABLE_BITCODE'] = 'NO'
            end
          end
          dynamic_project.save
        end
      end
    end
  end
end
